<?php
// +--------------------------------------------------------------------------+
// | Contentteller(R) 2.1.18                                                  |
// +--------------------------------------------------------------------------+
// | Copyright (C) 2002 - 2016 by Esselbach Internet Solutions                |
// | Available from http://www.contentteller.com                              |
// +--------------------------------------------------------------------------+
// | Contentteller is not free software. You may not redistribute this file   |
// | or its derivatives without written permission.                           |
// +--------------------------------------------------------------------------+
// | Contentteller is a registered trademark.                                 |
// +--------------------------------------------------------------------------+
// | Patch #5                                                                 |
// +--------------------------------------------------------------------------+

/**
 * @package Contentteller
 * @subpackage Acquire
 * @copyright (C) 2002-2016 Esselbach Internet Solutions
 */

/**
 * class acquire
 * A class that contains routines to import data from a Storyteller CMS database
 * @author Philipp Louis Esselbach
 * @package Contentteller
 */
class acquire
{
	/**
	 * function dbconnect
	 * A function to connect to a Storyteller CMS MySQL database
	 * @author Philipp Louis Esselbach
	 */
	function dbconnect()
	{
		global $preferences, $words_acquire;
		$error = "";
		$import_db_link = @mysqli_connect( $preferences[ 'acquire_db_hostname' ], $preferences[ 'acquire_db_username' ], $preferences[ 'acquire_db_password' ], $preferences[ 'acquire_db_name' ] ) or $error = $words_acquire[ 'FATAL_CAN_NOT_CONNECT_SERVER' ];

		return $error;
	}
	/**
	 * function dbclose
	 * A function to close the connection to the Storyteller CMS MySQL database
	 * @author Philipp Louis Esselbach
	 */
	function dbclose()
	{
		global $import_db_link;
		mysqli_close( $import_db_link );
	}
	/**
	 * function users
	 * A function to get the the number of user accounts from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function users()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(user_id) FROM esselbach_st_users" );
		list( $users ) = mysqli_fetch_row( $query );
		return $users;
	}
	/**
	 * function usersimport
	 * A function to import user accounts from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function usersimport( $start, $users )
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_users LIMIT " . intval( $start ) . ", " . intval( $users ) );

		if( mysqli_num_rows( $query ) )
		{
			$users = array();

			while( $usersarray = mysqli_fetch_array( $query ) )
			{
				$users[ ] = $usersarray;
			}
		}
		else
		{
			$users = 0;
		}

		return $users;
	}
	/**
	 * function content
	 * A function to get the the number of content pages from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function content()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(page_id) FROM esselbach_st_pages" );
		list( $pages ) = mysqli_fetch_row( $query );
		return $pages;
	}
	/**
	 * function contentpagesimport
	 * A function to import content pages from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function contentpagesimport( $start, $pages )
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_pages LIMIT " . intval( $start ) . ", " . intval( $pages ) );

		if( mysqli_num_rows( $query ) )
		{
			$contentpages = array();

			while( $contentpagesarray = mysqli_fetch_array( $query ) )
			{
				$contentpages[ ] = $contentpagesarray;
			}
		}
		else
		{
			$contentpages = 0;
		}

		return $contentpages;
	}
	/**
	 * function newscategories
	 * A function to get the the number of news categories from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function newscategories()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(category_id) FROM esselbach_st_categories" );
		list( $newscategories ) = mysqli_fetch_row( $query );
		return $newscategories;
	}
	/**
	 * function newscategoriesimport
	 * A function to import news categories from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function newscategoriesimport()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_categories" );

		if( mysqli_num_rows( $query ) )
		{
			$newscategories = array();

			while( $newscategoriesarray = mysqli_fetch_array( $query ) )
			{
				$newscategories[ ] = $newscategoriesarray;
			}
		}
		else
		{
			$newscategories = 0;
		}

		return $newscategories;
	}
	/**
	 * function newsstories
	 * A function to get the the number of news stories from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function newsstories()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(story_id) FROM esselbach_st_stories" );
		list( $newsstories ) = mysqli_fetch_row( $query );
		return $newsstories;
	}
	/**
	 * function newsstoriesimport
	 * A function to import news stories from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function newsstoriesimport( $start, $stories )
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_stories LIMIT " . intval( $start ) . ", " . intval( $stories ) );

		if( mysqli_num_rows( $query ) )
		{
			$newsstories = array();

			while( $newsstoriesarray = mysqli_fetch_array( $query ) )
			{
				$newsstories[ ] = $newsstoriesarray;
			}
		}
		else
		{
			$newsstories = 0;
		}

		return $newsstories;
	}
	/**
	 * function newsattachments
	 * Dummy function to return zero news attachments
	 * @author Philipp Louis Esselbach
	 */
    function newsattachments()
    {
    	return 0;
    }
	/**
	 * function newscomments
	 * A function to get the the number of news comments from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function newscomments()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(comment_id) FROM esselbach_st_comments WHERE comment_category = '1'" );
		list( $newscomments ) = mysqli_fetch_row( $query );
		return $newscomments;
	}
	/**
	 * function newscommentsimport
	 * A function to import news comments from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function newscommentsimport( $start, $comments )
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_comments WHERE comment_category = '1' LIMIT " . intval( $start ) . ", " . intval( $comments ) );

		if( mysqli_num_rows( $query ) )
		{
			$newscomments = array();

			while( $newscommentsarray = mysqli_fetch_array( $query ) )
			{
				$query2 = mysqli_query($import_db_link, "SELECT user_id FROM esselbach_st_users WHERE user_name = '" . addslashes( $newscommentsarray[ 'comment_author' ] ) . "'" );
				list( $user_id ) = mysqli_fetch_row( $query2 );
				$newscommentsarray[ 'comment_author_id' ] = $user_id;
				$newscomments[ ] = $newscommentsarray;
			}
		}
		else
		{
			$newscomments = 0;
		}

		return $newscomments;
	}
	/**
	 * function articlescategories
	 * A function to get the the number of article/review categories from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function articlescategories()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(reviewcat_id) FROM esselbach_st_reviewcat" );
		list( $articlescategories ) = mysqli_fetch_row( $query );
		return $articlescategories;
	}
	/**
	 * function articlescategoriesimport
	 * A function to import article/review categories from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function articlescategoriesimport()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_reviewcat" );

		if( mysqli_num_rows( $query ) )
		{
			$articlescategories = array();

			while( $articlescategoriesarray = mysqli_fetch_array( $query ) )
			{
				$articlescategories[ ] = $articlescategoriesarray;
			}
		}
		else
		{
			$articlescategories = 0;
		}

		return $articlescategories;
	}
	/**
	 * function articles
	 * A function to get the the number of articles/reviews from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function articles()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(review_id) FROM esselbach_st_review" );
		list( $articles ) = mysqli_fetch_row( $query );
		return $articles;
	}
	/**
	 * function articlesimport
	 * A function to import articles/reviews from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function articlesimport( $start, $entries )
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_review LIMIT " . intval( $start ) . ", " . intval( $entries ) );

		if( mysqli_num_rows( $query ) )
		{
			$articles = array();

			while( $articlesarray = mysqli_fetch_array( $query ) )
			{
				$articles[ ] = $articlesarray;
			}
		}
		else
		{
			$articles = 0;
		}

		return $articles;
	}
	/**
	 * function knowledgebasecategories
	 * A function to get the the number of knowledgebase/FAQ categories from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function knowledgebasecategories()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(faqcat_id) FROM esselbach_st_faqcat" );
		list( $knowledgebasecategories ) = mysqli_fetch_row( $query );
		return $knowledgebasecategories;
	}
	/**
	 * function knowledgebasecategoriesimport
	 * A function to import knowledgebase/FAQ categories from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function knowledgebasecategoriesimport()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_faqcat" );

		if( mysqli_num_rows( $query ) )
		{
			$knowledgebasecategories = array();

			while( $knowledgebasecategoriesarray = mysqli_fetch_array( $query ) )
			{
				$knowledgebasecategories[ ] = $knowledgebasecategoriesarray;
			}
		}
		else
		{
			$knowledgebasecategories = 0;
		}

		return $knowledgebasecategories;
	}
	/**
	 * function knowledgebaseentries
	 * A function to get the the number of knowledgebase/FAQ entries from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function knowledgebaseentries()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(faq_id) FROM esselbach_st_faq" );
		list( $knowledgebaseentries ) = mysqli_fetch_row( $query );
		return $knowledgebaseentries;
	}
	/**
	 * function knowledgebaseimport
	 * A function to import knowledgebase/FAQ entries from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function knowledgebaseimport( $start, $entries )
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_faq LIMIT " . intval( $start ) . ", " . intval( $entries ) );

		if( mysqli_num_rows( $query ) )
		{
			$knowledgebaseentries = array();

			while( $knowledgebaseentriesarray = mysqli_fetch_array( $query ) )
			{
				$knowledgebaseentries[ ] = $knowledgebaseentriesarray;
			}
		}
		else
		{
			$knowledgebaseentries = 0;
		}

		return $knowledgebaseentries;
	}
	/**
	 * function filescategories
	 * A function to get the the number of file categories from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function filescategories()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(downloadscat_id) FROM esselbach_st_downloadscat" );
		list( $filescategories ) = mysqli_fetch_row( $query );
		return $filescategories;
	}
	/**
	 * function filescategoriesimport
	 * A function to import file categories from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function filescategoriesimport()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_downloadscat" );

		if( mysqli_num_rows( $query ) )
		{
			$filescategories = array();

			while( $filescategoriesarray = mysqli_fetch_array( $query ) )
			{
				$filescategories[ ] = $filescategoriesarray;
			}
		}
		else
		{
			$filescategories = 0;
		}

		return $filescategories;
	}
	/**
	 * function files
	 * A function to get the the number of files from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function files()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(download_id) FROM esselbach_st_downloads" );
		list( $files ) = mysqli_fetch_row( $query );
		return $files;
	}
	/**
	 * function filesimport
	 * A function to import files from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function filesimport( $start, $entries )
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_downloads LIMIT " . intval( $start ) . ", " . intval( $entries ) );

		if( mysqli_num_rows( $query ) )
		{
			$files = array();

			while( $filesarray = mysqli_fetch_array( $query ) )
			{
				$files[ ] = $filesarray;
			}
		}
		else
		{
			$files = 0;
		}

		return $files;
	}
	/**
	 * function filescomments
	 * A function to get the the number of file comments from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function filescomments()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(comment_id) FROM esselbach_st_comments WHERE comment_category = '3'" );
		list( $filescomments ) = mysqli_fetch_row( $query );
		return $filescomments;
	}
	/**
	 * function filescommentsimport
	 * A function to import file comments from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function filescommentsimport( $start, $comments )
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_comments WHERE comment_category = '3' LIMIT " . intval( $start ) . ", " . intval( $comments ) );

		if( mysqli_num_rows( $query ) )
		{
			$filescomments = array();

			while( $filescommentsarray = mysqli_fetch_array( $query ) )
			{
				$query2 = mysqli_query($import_db_link, "SELECT user_id FROM esselbach_st_users WHERE user_name = '" . addslashes( $filescommentsarray[ 'comment_author' ] ) . "'" );
				list( $user_id ) = mysqli_fetch_row( $query2 );
				$filescommentsarray[ 'comment_author_id' ] = $user_id;
				$filescomments[ ] = $filescommentsarray;
			}
		}
		else
		{
			$filescomments = 0;
		}

		return $filescomments;
	}
	/**
	 * function glossary
	 * A function to get the the number of glossray entries from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function glossary()
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT COUNT(glossary_id) FROM esselbach_st_glossary" );
		list( $pages ) = mysqli_fetch_row( $query );
		return $pages;
	}
	/**
	 * function glossaryimport
	 * A function to import glossary entries from a Storyteller CMS database
	 * @author Philipp Louis Esselbach
	 */
	function glossaryimport( $start, $entries )
	{
		global $import_db_link;
		$query = mysqli_query($import_db_link, "SELECT * FROM esselbach_st_glossary LIMIT " . intval( $start ) . ", " . intval( $entries ) );

		if( mysqli_num_rows( $query ) )
		{
			$glossaryentries = array();

			while( $glossaryentriesarray = mysqli_fetch_array( $query ) )
			{
				$glossaryentries[ ] = $glossaryentriesarray;
			}
		}
		else
		{
			$glossaryentries = 0;
		}

		return $glossaryentries;
	}
}
?>